import { View, Text } from '@tarojs/components'
import { useCallback, useEffect, useMemo, useRef, useState, memo } from 'react'
import styles from './index.module.scss'
import classnames from 'classnames'
import Iconfont from '../iconfont/iconfont'
// 弹窗选择向上弹窗还是向下弹窗
type Direction = 'up' | 'down'
// 配置 菜单可选项
type Options = {
  text: string
  value: number
}

interface DropDownEvent {
  change: (value: Options['value']) => void   // value 变化时触发
}

interface PropsType extends DropDownEvent{
  direction?: Direction
  title: string             // 已选中的菜单标题
  options?: Options[]
  value?: number | string     // 当前选中的值
  children?: React.ReactNode
  activeColor?: string
}

export default (props: PropsType) => {
  const { children, direction = 'down', title, value, options, change, activeColor } = props

  const defaultOptions = () => {
    return options?.map(({text, value})=>{
      return (
        <View>
          <Text>{text}</Text>
          <Iconfont name='icon-bianji' size={40} color={value !== options[0].value ? activeColor : '#333'}></Iconfont>
        </View>
      )

    })
  }

  return (
    <View className={styles.dropDownItem}>
      <View >
        <Text className='' style={{ color: activeColor }}>
          {title}
        </Text>
        <Iconfont name='icon-bianji' size={40} color={value !== options![0].value ? activeColor : '#333'}></Iconfont>
      </View>
      {children ? children : defaultOptions()}
    </View>
  )
}
